@@ -2,14 +2,15 @@
 
 #include <QObject>
 #include <QtMultimedia/QMediaPlayer>
+#include <QtMultimedia/QAudioOutput>
 
 class PowerManagementInterface;
 class Player : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QUrl url READ getUrl WRITE setUrl NOTIFY urlChanged)
-    Q_PROPERTY(int volume READ getVolume WRITE setVolume NOTIFY volumeChanged)
-    Q_PROPERTY(QMediaPlayer::State state READ getState NOTIFY stateChanged)
+    Q_PROPERTY(qreal volume READ getVolume WRITE setVolume NOTIFY volumeChanged)
+    Q_PROPERTY(QMediaPlayer::PlaybackState state READ getState NOTIFY stateChanged)
     Q_PROPERTY(int duration READ getDuration NOTIFY durationChanged)
     Q_PROPERTY(bool playing READ getPlaying NOTIFY playingChanged)
     Q_PROPERTY(int pos READ getPos WRITE setPos NOTIFY posChanged)
@@ -20,12 +21,12 @@ public:
     void setUrl(const QUrl &value);
     QUrl getUrl() const;
 
-    void setVolume(const int &value);
-    int getVolume() const;
+    void setVolume(const qreal &value);
+    qreal getVolume() const;
 
     int getDuration() const;
 
-    QMediaPlayer::State getState() const;
+    QMediaPlayer::PlaybackState getState() const;
     bool getPlaying() const;
 
     int getPos() const;
@@ -40,10 +41,11 @@ public Q_SLOTS:
 
 private:
     QMediaPlayer *player;
+    QAudioOutput *m_output;
     QUrl url;
     PowerManagementInterface *m_power;
     int amountBuffers = 0;
-    int volume = 100;
+    qreal volume = 1.0;
 
 Q_SIGNALS:
     void durationChanged();
